# Components 

Entropy components represent instruments or dependencies to your experiment.

They can be saved in the entropy database by the user. This reduced code duplication when writing new experiments using the pipeline engine. 

In principle, any class can be saved to the database as representing a component (any resource), but if the wrapper 
classes provided here are used, more data can be automatically saved to the database when experiments are run. 

